@@ -1,11 +1,16 @@
-package Sample::Module;
+package Module;
+
+use strict;
+use warnings;
 
 sub foo {
- 	# foo foo foo
+
+    # foo foo foo
 }
 
 sub bar {
-	# bar bar bar
+
+    # bar bar bar
 }
 
 1;
@@ -14,7 +19,7 @@ __END__
 
 =head1 NAME
 
-Sample::Module - Sample Module
+Module - Sample Module
 
 =head1 SYNOPSIS
 
@@ -30,10 +35,6 @@ foo foo foo
 
 bar bar bar
 
-=head1 SEE ALSO
-
-L<Sample::Project>
-
 =head1 CHARACTER ESCAPES
 
 E<lt> E<gt> E<verbar> E<sol> E<eacute> E<0x201E> E<075> E<181>
